//
//  BookListView.swift
//  UniversalLinkSample
//
//  Created by Loris Perret on 30/07/2024.
//

import SwiftUI

struct BookListView: View {
    
    // MARK: - Properties

    let books: [Book]
    @State private var path = [Book]()
    
    // MARK: - Body

    var body: some View {
        NavigationStack(path: $path) {
            List {
                ForEach(books) { book in
                    NavigationLink {
                        BookView(book: book)
                    } label: {
                        VStack(alignment: .leading) {
                            Text("\(book.title)")
                            Text("- \(book.author)")
                        }
                    }
                }
            }
            .padding(.top, 20)
            .scrollContentBackground(.hidden)
            .navigationTitle("Book List")
            .background(.black.opacity(0.05))
            .navigationDestination(for: Book.self) { BookView(book: $0) }
            .onOpenURL(perform: { url in
                if let id = Int(url.lastPathComponent),
                   let book = books.first(where: { $0.id == id }) {
                    path.append(book)
                }
            })
        }
    }
}

#Preview {
    BookListView(books: Book.Mock.previewList)
}
